@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6loganon.c
- * Version    : $Id: ipv6loganon.c,v 1.6 2007/04/26 09:57:31 peter Exp $
- * Copyright  : 2007 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6loganon.c,v 1.8 2011/05/12 10:30:47 peter Exp $
+ * Copyright  : 2007-2011 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile anonymization
@@ -64,6 +64,11 @@ static char     cache_lru_key_token[CACHE_LRU_SIZE][NI_MAXHOST];
 static char     cache_lru_value[CACHE_LRU_SIZE][NI_MAXHOST];
 static long int cache_lru_statistics[CACHE_LRU_SIZE];
 
+char	file_out[NI_MAXHOST] = "";
+int	file_out_flag = 0;
+int	file_out_flush = 0;
+char	file_out_mode[NI_MAXHOST] = "";
+FILE	*FILE_OUT;
 
 /**************************************************/
 /* main */
@@ -96,6 +101,30 @@ int main(int argc,char *argv[]) {
 				ipv6calc_debug = atol(optarg);
 				break;
 
+			case 'f':
+				file_out_flush = 1;
+				break;
+
+			case 'w':
+			case 'a':
+				if (strlen(optarg) < NI_MAXHOST) {
+					strcpy(file_out, optarg);
+					file_out_flag = 1;
+				} else {
+					fprintf(stderr, " Output file too long: %s\n", optarg);
+					exit(EXIT_FAILURE);
+				};
+
+				switch (i) {
+					case 'w':
+						strcpy(file_out_mode, "w");
+						break;
+					case 'a':
+						strcpy(file_out_mode, "a");
+						break;	
+				};
+				break;
+
 			case 'c':
 				cache_lru_limit = atoi(optarg);
 				if (cache_lru_limit > CACHE_LRU_SIZE) {
@@ -159,8 +188,39 @@ int main(int argc,char *argv[]) {
 	argv += optind;
 	argc -= optind;
 
+	if (file_out_flag == 1) {
+		if (ipv6calc_debug > 0) {
+			fprintf(stderr, "Output file specified: %s\n", file_out);
+		};
+
+		FILE_OUT = fopen(file_out, file_out_mode);
+		if (! FILE_OUT) {
+			fprintf(stderr, "Can't open Output file: %s\n", file_out);
+			exit(EXIT_FAILURE);
+		} else {
+			if (ipv6calc_debug > 0) {
+				if (strcmp(file_out_mode, "a") == 0) {
+					fprintf(stderr, "Output file opened successfully in append mode: %s\n", file_out);
+				} else {
+					fprintf(stderr, "Output file opened successfully in write mode: %s\n", file_out);
+				};
+			};
+			file_out_flag = 2;
+		};
+	};
+
 	lineparser();
 
+	if (file_out_flag == 2) {
+		if (ipv6calc_debug > 0) {
+			fprintf(stderr, "Output file is closed now: %s\n", file_out);
+		};
+		fflush(FILE_OUT);
+		fclose(FILE_OUT);
+	} else {
+		fflush(stdout);
+	};
+
 	exit(EXIT_SUCCESS);
 };
 #undef DEBUG_function_name
@@ -246,11 +306,25 @@ static void lineparser(void) {
 		
 		/* print result and rest of line, if available */
 		if (*ptrptr[0] != '\0') {
-			printf("%s %s", resultstring, *ptrptr);
-			fflush(stdin);
+			if (file_out_flag == 2) {
+				fprintf(FILE_OUT, "%s %s", resultstring, *ptrptr);
+			} else {
+				printf("%s %s", resultstring, *ptrptr);
+			};
 		} else {
-			printf("%s\n", resultstring);
-			fflush(stdin);
+			if (file_out_flag == 2) {
+				fprintf(FILE_OUT, "%s\n", resultstring);
+			} else {
+				printf("%s\n", resultstring);
+			};
+		};
+
+		if (file_out_flush == 1) {
+			if (file_out_flag == 2) {
+				fflush(FILE_OUT);
+			} else {
+				fflush(stdout);
+			};
 		};
 	};
 
@@ -383,7 +457,7 @@ static int anonymizetoken(char *resultstring, const char *token) {
 		libipv6addr_anonymize(&ipv6addr, mask_iid, mask_ipv6, mask_ipv4);
 
 		/* convert IPv6 address structure to string */
-		libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, 0);
+		ipv6addrstruct_to_compaddr(&ipv6addr, resultstring);
 
 	} else if (ipv4addr.flag_valid == 1) {
 		/* anonymize IPv6 address according to settings */
