@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calchelp.c
- * Version    : $Id: ipv6calchelp.c,v 1.18 2010/05/20 14:49:38 peter Exp $
- * Copyright  : 2002-2009 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calchelp.c,v 1.24 2011/10/08 11:53:23 peter Exp $
+ * Copyright  : 2002-2011 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Help library
@@ -80,7 +80,7 @@ void printhelp_inputtypes(const uint32_t formatoptions) {
 	};
 
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) {	
-		snprintf(printformatstring, sizeof(printformatstring) - 1, "  %%-%ds: %%s\n", (int) maxlen);
+		snprintf(printformatstring, sizeof(printformatstring) - 1, "  %%-%ds : %%s\n", (int) maxlen);
 	} else {
 		snprintf(printformatstring, sizeof(printformatstring) - 1, "%%-%ds\n", (int) maxlen);
 	}
@@ -141,7 +141,7 @@ void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoption
 	};
 
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) {	
-		snprintf(printformatstring, sizeof(printformatstring) - 1, "  %%-%ds: %%s\n", (int) maxlen);
+		snprintf(printformatstring, sizeof(printformatstring) - 1, "  %%-%ds : %%s\n", (int) maxlen);
 	} else {
 		snprintf(printformatstring, sizeof(printformatstring) - 1, "%%-%ds\n", (int) maxlen);
 	};
@@ -175,9 +175,10 @@ void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoption
 			if (ipv6calc_debug != 0) {
 				fprintf(stderr, "Row %d: %08x - %08x\n", i, (unsigned int) ipv6calc_formatmatrix[i][0], (unsigned int) ipv6calc_formatmatrix[i][1]);
 			};
+
 			if ((ipv6calc_formatmatrix[i][1] & ipv6calc_formatstrings[j].number) != 0) {
 				/* available for output, look for name now */
-				if (ipv6calc_formatstrings[j].number == ipv6calc_formatmatrix[i][0]) {
+				if (strlen(ipv6calc_formatstrings[j].explanation) > 0) {
 					fprintf(stderr, printformatstring, ipv6calc_formatstrings[j].token, ipv6calc_formatstrings[j].explanation);
 				} else {
 					fprintf(stdout, printformatstring, ipv6calc_formatstrings[j].token, "(empty)");
@@ -197,9 +198,9 @@ void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoption
 
 /* list of action types */
 void printhelp_actiontypes(const uint32_t formatoptions) {
-	int j;
+	int i, j, o, test = 2, has_options = 0;
 	size_t maxlen = 0;
-	char printformatstring[20];
+	char printformatstring[20], printformatstring2[20], printformatstring3[20];
 	
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) {	
 		printversion();
@@ -219,11 +220,14 @@ void printhelp_actiontypes(const uint32_t formatoptions) {
 	};
 
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) {
-		snprintf(printformatstring, sizeof(printformatstring) - 1, "  %%-%ds: %%s\n", (int) maxlen);
+		snprintf(printformatstring, sizeof(printformatstring) - 1, "  %%-%ds : %%s\n", (int) maxlen);
 	} else {
 		snprintf(printformatstring, sizeof(printformatstring) - 1, "%%-%ds\n", (int) maxlen);
 	};
 
+	snprintf(printformatstring2, sizeof(printformatstring2) - 1, "  %%-%ds%%s\n", (int) maxlen + 4);
+	snprintf(printformatstring3, sizeof(printformatstring3) - 1, "  %%-%ds--%%s", (int) maxlen + 5);
+
 	if (ipv6calc_debug != 0) {
 		fprintf(stderr, "Format string: %s\n", printformatstring);
 	};
@@ -234,8 +238,51 @@ void printhelp_actiontypes(const uint32_t formatoptions) {
 		if (ipv6calc_debug != 0) {
 			fprintf(stderr, "Format-Row %d: %08x - %s - %s\n", j, (unsigned int) ipv6calc_actionstrings[j].number, ipv6calc_actionstrings[j].token, ipv6calc_actionstrings[j].explanation);
 		};
+
 		if ((formatoptions & FORMATOPTION_machinereadable) == 0) {
 			fprintf(stderr, printformatstring, ipv6calc_actionstrings[j].token, ipv6calc_actionstrings[j].explanation);
+
+			while (test != 0) {
+				if (test == 1) {	
+					fprintf(stderr, printformatstring2, "", "Required options:");
+				};
+
+				/* search for defined options */
+				for (i = 0; i < (int) (sizeof(ipv6calc_actionoptionmap) / sizeof(ipv6calc_actionoptionmap[0])); i++) {
+					if (ipv6calc_debug != 0) {
+						fprintf(stderr, "Option %d\n", i);
+					};
+
+					if (ipv6calc_actionstrings[j].number == ipv6calc_actionoptionmap[i][0]) {
+						if (ipv6calc_actionoptionmap[i][1] == 0) {
+							/* no options supported */
+							break;
+						};
+						
+						if (ipv6calc_debug != 0) {
+							fprintf(stderr, "Option value: %08x\n", (unsigned int) ipv6calc_actionoptionmap[i][1]);
+						};
+
+						/* run through options */
+						for (o = 0; o < (int) (sizeof(ipv6calc_longopts) / sizeof (ipv6calc_longopts[0])); o++) {
+							if ((ipv6calc_actionoptionmap[i][1] == ipv6calc_longopts[o].val)) {
+								has_options = 1;
+								if (test == 1) {	
+									fprintf(stderr, printformatstring3, "", ipv6calc_longopts[o].name);
+									if (ipv6calc_longopts[o].has_arg > 0) {
+										fprintf(stderr, " ...");
+									};
+									fprintf(stderr, "\n");
+								};
+							};
+						};
+					};
+				};
+				if (has_options == 0) {
+					break;
+				};
+				test--;
+			};
 		} else {
 			fprintf(stdout, printformatstring, ipv6calc_actionstrings[j].token);
 		};
@@ -246,16 +293,15 @@ void printhelp_actiontypes(const uint32_t formatoptions) {
 
 /* print global help */
 void printhelp(void) {
-	/* dummy assignment to prevent compiler warning about unused constant */
-	size_t maxlen = 0;
-	maxlen = strlen(ipv6calc_shortopts);
-
 	printversion();
 	printcopyright();
 	fprintf(stderr, "\n");
 	fprintf(stderr, " General:\n");
 	fprintf(stderr, "  [-d|--debug <debug value>] : debug value (bitwise like)\n");
-	fprintf(stderr, "  [-q|--quiet]               : be more quiet\n");
+	fprintf(stderr, "  [-q|--quiet]               : be more quiet (auto-enabled in pipe mode)\n");
+	fprintf(stderr, "  [-f|--flush]               : flush each line in pipe mode\n");
+	fprintf(stderr, "  -v                         : show version (and included features)\n");
+	fprintf(stderr, "  -v -v                      : show verbose version information\n");
 	fprintf(stderr, "\n");
 	fprintf(stderr, " Usage with new style options:\n");
 	fprintf(stderr, "  [--in|-I <input type>]   : specify input  type\n");
@@ -279,13 +325,30 @@ void printhelp(void) {
 	fprintf(stderr, "\n");
 	fprintf(stderr, "  [--db-ip2location-ipv4 <file>] : IP2Location IPv4 database file (optional)\n");
 	fprintf(stderr, "  [--db-ip2location-ipv6 <file>] : IP2Location IPv6 database file (optional)\n");
+#ifdef IP2LOCATION_DEFAULT_FILE_IPV4
+	fprintf(stderr, "  [--db-ip2location-ipv4-default|-L] : enable & use IP2Location IPv4 default database file (optional)\n");
+	fprintf(stderr, "                                        %s\n", IP2LOCATION_DEFAULT_FILE_IPV4);
+#endif
+#ifdef IP2LOCATION_DEFAULT_FILE_IPV6
+	fprintf(stderr, "  [--db-ip2location-ipv6-default|-L] : enable & use IP2Location IPv6 default database file (optional)\n");
+	fprintf(stderr, "                                        %s\n", IP2LOCATION_DEFAULT_FILE_IPV6);
+#endif
 #endif
 #ifdef SUPPORT_GEOIP
 	fprintf(stderr, "\n");
-	fprintf(stderr, "  [--db-geoip <file>]            : GeoIP database file (optional)\n");
-#ifdef GEOIP_DEFAULT_FILE
-	fprintf(stderr, "  [--db-geoip-default|-G]        : enable & use GeoIP default database file (optional):\n");
-	fprintf(stderr, "                                    %s\n", GEOIP_DEFAULT_FILE);
+	fprintf(stderr, "  [--db-geoip-ipv4 <file>]  : GeoIP IPv4 database file (optional)\n");
+#ifdef SUPPORT_GEOIP_V6
+	fprintf(stderr, "  [--db-geoip-ipv6 <file>]  : GeoIP IPv6 database file (optional)\n");
+#endif
+#ifdef GEOIP_DEFAULT_FILE_IPV4
+	fprintf(stderr, "  [--db-geoip-ipv4-default|-G] : enable & use GeoIP IPv4 default database file (optional)\n");
+	fprintf(stderr, "                                  %s\n", GEOIP_DEFAULT_FILE_IPV4);
+#endif
+#ifdef GEOIP_DEFAULT_FILE_IPV6
+#ifdef SUPPORT_GEOIP_V6
+	fprintf(stderr, "  [--db-geoip-ipv6-default|-G] : enable & use GeoIP IPv6 default database file (optional)\n");
+	fprintf(stderr, "                                  %s\n", GEOIP_DEFAULT_FILE_IPV6);
+#endif
 #endif
 #endif
 	fprintf(stderr, "\n");
